@@ -100,6 +100,7 @@ typedef struct{
 /** used for reading the offset file */
 typedef struct{
   unsigned int mUInt1;
+  //unsigned int mUInt2;
   streampos mStreampos;
 } SUIntStreampos;
 
@@ -119,6 +120,7 @@ typedef struct{
 bool CAcIFFileSystem::operator()()const{
   /**/gMutex->lock();
   bool lReturnValue(mURL2FTS
+		    && mInvertedFile
 		    && *mInvertedFile
 		    && mOffsetFile
 		    && mURL2FTS->operator bool());
@@ -409,6 +411,9 @@ void CAcIFFileSystem::writeOffsetFileElement(TID inFeatureID,
 
   lWriter.mUInt1=inFeatureID;
   lWriter.mStreampos=inPosition;
+#ifndef _NO_PRINT_OFFSET_CHECK
+  lWriter.mUInt2=int(inPosition);
+#endif
 
 //   inOpenOffsetFile.write((char*)&inFeatureID,
 // 			 sizeof(TID));
@@ -417,8 +422,8 @@ void CAcIFFileSystem::writeOffsetFileElement(TID inFeatureID,
   inOpenOffsetFile.write((char*)&lWriter,
  			 sizeof(lWriter));
   std::cout << "[inFeatureID:" << sizeof(TID) << "/" << inFeatureID
-	    << ";inPosition:" << sizeof(streampos) << "/" << inPosition 
-	    << "]" << endl;
+	    << ";inPosition:" << sizeof(streampos) << "/" << inPosition << "==" << int(inPosition)
+	    << "]" << sizeof(lWriter) << endl;
   /**/gMutex->unlock();
   
 };
@@ -641,7 +646,7 @@ bool CAcIFFileSystem::newGenerateInvertedFile(){
 	/* this writes the actual data for the feature, 
 	   meaning the list of all the documents containg 
 	   this feature */
-	cout << endl
+	cout //<< endl
 	     << "Writing Chunk for Feature ID "
 	     << hex
 	     << lFeatureID
@@ -979,71 +984,85 @@ bool CAcIFFileSystem::init(bool inMemory)
 
   mOffsetFile.seekg(0);
 
+
   /* while there is no end of file for the offsets */
   while(mOffsetFile){
     SUIntStreampos lVal;
 
     /* read a value into the offset file */
     mOffsetFile.read((char*)&lVal,sizeof(lVal));
-
-
-    unsigned int lFeatureID=lVal.mUInt1;
-    streampos lOffset(lVal.mStreampos);//FIXME streampos
+    
 
     if(mOffsetFile){
+
+
+      // actually useful code here! ;-I
+      unsigned int lFeatureID=lVal.mUInt1;
+      streampos lOffset(lVal.mStreampos);//FIXME streampos
       mMaximumFeatureID=(mMaximumFeatureID < lFeatureID)?lFeatureID:mMaximumFeatureID;
-      
       mIDToOffset[lFeatureID]=lOffset;
-    }
 
-
-    cout << "[read:lVal" << flush
-	 << hex
-	 << lFeatureID
-	 << ","
-	 << dec
-	 << lOffset
-	 << "]" << endl;
 #ifndef _NO_PRINT_OFFSET_CHECK
-#endif
-    //Reading the offsetfile
-    {
-      //move to the right position
-      mInvertedFile->seekg(lOffset);
-
-      //read the list start chunk 
-      //(by constructing an instance of the list start cunk)
-      CIFListStart lListStart(*mInvertedFile);
-
-      //checking it
-      if(lListStart.getFeatureID()!=lFeatureID){
-	cout << "[ERROR" << flush
-	     << hex
-	     << lFeatureID
-	     << ","
-	     << hex
-	     << lListStart.getFeatureID()
-	     << dec
-	     << "]" << flush;
-	assert(0);
+      // hexdump of the characters read
+      for(int i=0;i<sizeof(lVal);i++){
+	cout << hex << (unsigned int)(((unsigned char*)&lVal)[i]) << "/" << dec << flush;
       }
-#ifndef _NO_PRINT_OFFSET_CHECK
-      else{
-	cout << "-" << flush;
-      }
-#endif
-
-      //And setting up the translation table from feature 
-      //ID to collection frequency
-      mFeatureToCollectionFrequency[lListStart.getFeatureID()]=
-	lListStart.getCollectionFrequency();
       
-      /*      assert(mFeatureToCollectionFrequency[lListStart.getFeatureID()]);*/
 
-    }
+      // value different from check value?
+      if((unsigned int)(lVal.mStreampos) != lVal.mUInt2){
+	cout << "Size:" << sizeof(lVal) << ":"  << lVal.mUInt1 << ":" << lVal.mStreampos << "!=" << lVal.mUInt2 << "!!!" << long(mOffsetFile.tellg()) << endl;
+      }
+      assert((unsigned int)(lVal.mStreampos) == lVal.mUInt2);
+
+      // the actual values
+      cout << "[read:" << sizeof(lVal) << ":inFeatureID:" << flush
+	   << hex
+	   << lFeatureID << "==" << dec << lFeatureID
+	   << ";inPosition:"
+	   << dec
+	   << lOffset
+	   << "/"
+	   << lVal.mStreampos
+	   << "]" << long(mOffsetFile.tellg()) << endl;
+#endif
+      //Reading the offsetfile
+      { //move to the right position
+	mInvertedFile->seekg(lOffset);
+	
+	//read the list start chunk 
+	//(by constructing an instance of the list start cunk)
+	CIFListStart lListStart(*mInvertedFile);
+	
+	//checking it
+	if(lListStart.getFeatureID()!=lFeatureID){
+	  cout << "[ERROR" << flush
+	       << hex
+	       << lFeatureID
+	       << ","
+	       << hex
+	       << lListStart.getFeatureID()
+	       << dec
+	       << "]" << flush;
+	  assert(0);
+	}
+#ifndef _NO_PRINT_OFFSET_CHECK
+	else{
+	  cout << "-" << flush;
+	}
+#endif
+
+	//And setting up the translation table from feature 
+	//ID to collection frequency
+	mFeatureToCollectionFrequency[lListStart.getFeatureID()]=
+	  lListStart.getCollectionFrequency();
+	
+	/*      assert(mFeatureToCollectionFrequency[lListStart.getFeatureID()]);*/
+	
+      }
 #ifndef _NO_CHECK_OFFSET_FILE
 #endif
-    
+    } // if the file is valid --> ID is valid!
   }
 
   cout << "OffsetFile " 
