@@ -1,18 +1,18 @@
 //configuration files for sessions and algorithms/collections
 
 //Sockets
-#include <time.h>
+#include <ctime>
 #include <unistd.h>
 #include <fcntl.h>
 #include <sys/time.h>
 #include <sys/types.h>
 #include <sys/socket.h>
-#include <errno.h>
+#include <cerrno>
 //
 #include "libMRML/include/CXEVCommunication.h" // the visitor analyzing the document trees built
 #include "libMRML/include/CCommunicationHandler.h"
 #include <string>
-#include <stdio.h>
+#include <cstdio>
 #include <stdlib.h>
 #include "libMRML/include/mrml_const.h" //mrml string constants newStart/EndMRMLElement
 #include "../include/CTimeStampGenerator.h" // for time stamps
@@ -675,6 +675,8 @@ bool CCommunicationHandler::readAndParse(){
 	   << XML_ErrorString(XML_GetErrorCode(mParser))
 	   << " at line "
 	   << XML_GetCurrentLineNumber(mParser)
+	   << endl
+	   << "The cstdio stream was " << mSocket
 	   << endl;
       lSuccess=false;
     }	
@@ -878,7 +880,8 @@ CCommunicationHandler::~CCommunicationHandler(){
     
     startMultiRequest clears the message which is going to be built.
 */
-void CCommunicationHandler::startMultiRequest(const string& inSessionID){
+void CCommunicationHandler::startMultiRequest(const string& inSessionID,
+					      const string& inLanguageCode){
   mMultiResponse=new CXMLElement("mrml",0);
   mMultiResponse->addAttribute("session-id",
 			       inSessionID);
@@ -895,10 +898,14 @@ void CCommunicationHandler::endMultiRequest(){
 				 "and-of-course-for-fun");
     CTimeStampGenerator lGenerator;
     addToMultiResponse(lGenerator.generateTimeStamp());
-
+#warning FIXME add response translation here
+    if(mMultiResponse->stringReadAttribute(mrml_const::session_id).first){
+      mSessionManager.translate(mMultiResponse->stringReadAttribute(mrml_const::session_id).second,
+				*mMultiResponse);
+    }
+    
     gMutex->lock();
     mMultiResponse->toXML(lMessage);
-
     cout << "endMultiRequest: WRITING: "
 	 << lMessage
 	 << endl;
